==> goods-inner-api-0.0.7-20221227.123155-11-sources.jar: cn/com/duiba/goods/inner/api/dto/UnshippedOrderDTO.java <==
package cn.com.duiba.goods.inner.api.dto;

import java.io.Serializable;

/**
 * 待发货订单展示实体
 * Created by guoyanfei .
 * 2022/12/14 .
 */
public class UnshippedOrderDTO implements Serializable {

    private static final long serialVersionUID = 2577643558128749282L;
    
    /**
     * 订单号
     */
    private String orderNo;

    /**
     * 商品图片，sku图片>批量设置sku图>spu首图
     */
    private String snapshotGoodsImg;

    /**
     * 商品名称快照
     */
    private String snapshotSpuName;

    /**
     * 规格内容快照
     */
    private String snapshotAttrs;

    /**
     * 商品数量
     */
    private Integer quantity;

    /**
     * 发货物流信息
     */
    private OrderExpress orderExpress;

    public static class OrderExpress implements Serializable {

        private static final long serialVersionUID = -783526077016416121L;
        
        /**
         * 买家姓名
         */
        private String buyerName;

        /**
         * 买家手机号
         */
        private String buyerTel;

        /**
         * 省
         */
        private String province;

        /**
         * 市
         */
        private String city;

        /**
         * 区（县）
         */
        private String district;

        /**
         * 街道（镇）
         */
        private String street;

        /**
         * 详细地址
         */
        private String addrDetail;

        public String getBuyerName() {
            return buyerName;
        }

        public void setBuyerName(String buyerName) {
            this.buyerName = buyerName;
        }

        public String getBuyerTel() {
            return buyerTel;
        }

        public void setBuyerTel(String buyerTel) {
            this.buyerTel = buyerTel;
        }

        public String getProvince() {
            return province;
        }

        public void setProvince(String province) {
            this.province = province;
        }

        public String getCity() {
            return city;
        }

        public void setCity(String city) {
            this.city = city;
        }

        public String getDistrict() {
            return district;
        }

        public void setDistrict(String district) {
            this.district = district;
        }

        public String getStreet() {
            return street;
        }

        public void setStreet(String street) {
            this.street = street;
        }

        public String getAddrDetail() {
            return addrDetail;
        }

        public void setAddrDetail(String addrDetail) {
            this.addrDetail = addrDetail;
        }
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getSnapshotGoodsImg() {
        return snapshotGoodsImg;
    }

    public void setSnapshotGoodsImg(String snapshotGoodsImg) {
        this.snapshotGoodsImg = snapshotGoodsImg;
    }

    public String getSnapshotSpuName() {
        return snapshotSpuName;
    }

    public void setSnapshotSpuName(String snapshotSpuName) {
        this.snapshotSpuName = snapshotSpuName;
    }

    public String getSnapshotAttrs() {
        return snapshotAttrs;
    }

    public void setSnapshotAttrs(String snapshotAttrs) {
        this.snapshotAttrs = snapshotAttrs;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public OrderExpress getOrderExpress() {
        return orderExpress;
    }

    public void setOrderExpress(OrderExpress orderExpress) {
        this.orderExpress = orderExpress;
    }
}

==> goods-inner-api-0.0.8-sources.jar: cn/com/duiba/goods/inner/api/dto/UnshippedOrderDTO.java <==
package cn.com.duiba.goods.inner.api.dto;

import cn.com.duiba.goods.common.dto.AccountInfo;

import java.io.Serializable;
import java.util.List;

/**
 * 待发货订单展示实体
 * Created by guoyanfei .
 * 2022/12/14 .
 */
public class UnshippedOrderDTO implements Serializable {

    private static final long serialVersionUID = 2577643558128749282L;

    /**
     * 订单号
     */
    private String orderNo;

    /**
     * 商品图片，sku图片>批量设置sku图>spu首图
     */
    private String snapshotGoodsImg;

    /**
     * 商品名称快照
     */
    private String snapshotSpuName;

    /**
     * 规格内容快照
     */
    private String snapshotAttrs;

    /**
     * 商品数量
     */
    private Integer quantity;

    /**
     * 商品类型
     * {@link cn.com.duiba.goods.common.enums.goods.SpuType}
     */
    private Integer spuType;

    /**
     * 虚拟商品收货信息
     * spuType为2的时候这个字段不为空
     */
    private OrderVirtualInfo orderVirtualInfo;

    /**
     * 发货物流信息
     * spuType为1的时候这个字段不为空
     */
    private OrderExpress orderExpress;

    public static class OrderVirtualInfo implements Serializable {

        private static final long serialVersionUID = 3853748677949413767L;

        /**
         * 收货信息
         */
        private String accountInfo;

        /**
         * 兑换内容
         */
        private String goodsInfo;

        /**
         * 解析accountInfo并返回
         *
         * @return
         */
        public List<AccountInfo> getAccountInfoList() {
            return AccountInfo.parseList(accountInfo);
        }

        public String getAccountInfo() {
            return accountInfo;
        }

        public void setAccountInfo(String accountInfo) {
            this.accountInfo = accountInfo;
        }

        public String getGoodsInfo() {
            return goodsInfo;
        }

        public void setGoodsInfo(String goodsInfo) {
            this.goodsInfo = goodsInfo;
        }
    }

    public static class OrderExpress implements Serializable {

        private static final long serialVersionUID = -783526077016416121L;

        /**
         * 买家姓名
         */
        private String buyerName;

        /**
         * 买家手机号
         */
        private String buyerTel;

        /**
         * 省
         */
        private String province;

        /**
         * 市
         */
        private String city;

        /**
         * 区（县）
         */
        private String district;

        /**
         * 街道（镇）
         */
        private String street;

        /**
         * 详细地址
         */
        private String addrDetail;

        public String getBuyerName() {
            return buyerName;
        }

        public void setBuyerName(String buyerName) {
            this.buyerName = buyerName;
        }

        public String getBuyerTel() {
            return buyerTel;
        }

        public void setBuyerTel(String buyerTel) {
            this.buyerTel = buyerTel;
        }

        public String getProvince() {
            return province;
        }

        public void setProvince(String province) {
            this.province = province;
        }

        public String getCity() {
            return city;
        }

        public void setCity(String city) {
            this.city = city;
        }

        public String getDistrict() {
            return district;
        }

        public void setDistrict(String district) {
            this.district = district;
        }

        public String getStreet() {
            return street;
        }

        public void setStreet(String street) {
            this.street = street;
        }

        public String getAddrDetail() {
            return addrDetail;
        }

        public void setAddrDetail(String addrDetail) {
            this.addrDetail = addrDetail;
        }
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getSnapshotGoodsImg() {
        return snapshotGoodsImg;
    }

    public void setSnapshotGoodsImg(String snapshotGoodsImg) {
        this.snapshotGoodsImg = snapshotGoodsImg;
    }

    public String getSnapshotSpuName() {
        return snapshotSpuName;
    }

    public void setSnapshotSpuName(String snapshotSpuName) {
        this.snapshotSpuName = snapshotSpuName;
    }

    public String getSnapshotAttrs() {
        return snapshotAttrs;
    }

    public void setSnapshotAttrs(String snapshotAttrs) {
        this.snapshotAttrs = snapshotAttrs;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public OrderVirtualInfo getOrderVirtualInfo() {
        return orderVirtualInfo;
    }

    public void setOrderVirtualInfo(OrderVirtualInfo orderVirtualInfo) {
        this.orderVirtualInfo = orderVirtualInfo;
    }

    public OrderExpress getOrderExpress() {
        return orderExpress;
    }

    public void setOrderExpress(OrderExpress orderExpress) {
        this.orderExpress = orderExpress;
    }

    public Integer getSpuType() {
        return spuType;
    }

    public void setSpuType(Integer spuType) {
        this.spuType = spuType;
    }
}
